Class: Thoth::Cache::Noop

Inherits:
Object
  • Object
show all
Includes:
Innate::Cache::API
Defined in:
lib/thoth/cache.rb

Overview

This is a no-op cache API used when the cache is disabled in order to avoid having to make constant configuration checks.

Instance Method Summary collapse

Instance Method Details

#cache_clearObject



36
# File 'lib/thoth/cache.rb', line 36

def cache_clear; end

#cache_delete(key, *keys) ⇒ Object



38
39
40
# File 'lib/thoth/cache.rb', line 38

def cache_delete(key, *keys)
  nil
end

#cache_fetch(key, default = nil) ⇒ Object



42
43
44
# File 'lib/thoth/cache.rb', line 42

def cache_fetch(key, default = nil)
  default
end

#cache_setup(hostname, username, appname, cachename) ⇒ Object



46
# File 'lib/thoth/cache.rb', line 46

def cache_setup(hostname, username, appname, cachename); end

#cache_store(key, value, options = {}) ⇒ Object



48
49
50
# File 'lib/thoth/cache.rb', line 48

def cache_store(key, value, options = {})
  value
end